# this program Remove all consonants from string
 
test_str = "I am studying the course Tools and Techniques for Data Science"

print("The original string is : " + test_str)
res = []
for ch in test_str:
    if ch in "aeiouAEIOU":
        res.extend(ch)
res = " ".join(res)

print("String after consonants removal : " + str(res))


operations = {
    "+": lambda x, y: x + y,
    "-": lambda x, y: x - y,
    "*": lambda x, y: x * y,
    "/": lambda x, y: x / y,
}

def calculate(expr):
    numxChars = ""
    operation = None
    numyChars = ""
    for char in expr:
        if char.isdigit():
            if operation is None:
                numxChars += char
            else:
                numyChars += char
        elif char in operations:
            operation = char
        elif char.isspace:
            pass
        else:
            raise Exception("invalid charecter: " + char)
    return operations[operation](int(numxChars), int(numyChars))
    
print (calculate(input("Input? ")))


#This program calculates the lcm of 2 numbers

def Lcm():
    print('Enter two \'integers\' \n')
    try:
        num1 = int(input("Enter first number\n"))
        num2 = int(input("Enter second number\n"))
    except:
        print("The numbers must be of integer type")
    else:
        maxnbr = max(num1, num2)
        while(True):
            if(maxnbr % num1 == 0 and maxnbr % num2 == 0):
                break
            maxnbr+=1
    print('The lcm of given numbers is', maxnbr)
    
Lcm()


#This program swaps the 1st and last elements of a list

def Swap(mylist):
    size = len(mylist)
    temp = mylist[0]
    mylist[0] = mylist[size-1]
    mylist[size-1] = temp

    return mylist

lista = [12, 23, 45, 95, 10]
print('Original list: ', lista)
print('List after swaping: ', Swap(lista))



def Cir (radius):
    #Calculates the area of circle 
    arc = 3.14*radius*radius
    print("Area of Circle is ", arc)


def Rect (length, width):
    #Calculates the area of Rectangle 
    arr = length * width
    print("Area of Rectangle is ", arr)


def Sqr (side):
    #Calculates the area of Square 
    ars = side ** 2
    print("Area of Square is ", ars)

    
def Tri (base, height):
    #Calculates the area of Triangle 
    art = 0.5 * (base * height)
    print("Area of triangle is ", art)

Cir(2)
Rect(25, 20)
Sqr(30)
Tri(30, 30)


def checkprime():
    print("Enter a number ")
    try:
        nbr = int(input())
        count = 0
    except:
        print("The number must be of integer type")
    else:
        if(nbr > 1):
            for i in range(1, nbr + 1):
                if(nbr % i == 0):
                    count+=1
            if(count == 2):
                print('Number is prime')
            else:
                print("The number is not prime")

checkprime()
